@@ -23,7 +23,7 @@
 //! - Because UDP is a "connectionless" protocol, it offers no guarantee of "conversation" between traditional client and server roles. All the UDP transport layer gives you is a method to listen for messages thrown at you, and to throw messages at someone. Owing to this, CoAP machines are expected to perform both client and server roles (or more accurately, _sender_ and _receiver_ roles)
 //! - While _classes_ of status codes are the same (Success 2xx -> 2.xx, Client error 4xx -> 4.xx, Server error 5xx -> 5.xx), the semantics of the individual response codes differ.
 
-#![doc(html_root_url = "https://docs.rs/kwap/0.1.9")]
+#![doc(html_root_url = "https://docs.rs/kwap/0.1.10")]
 #![cfg_attr(all(not(test), feature = "no_std"), no_std)]
 #![cfg_attr(not(test),
             deny(missing_debug_implementations,
@@ -147,11 +147,23 @@ pub(crate) mod test {
 
   /// A mocked socket
   #[derive(Clone, Debug, Default)]
-  pub struct TubeSock(pub Option<SocketAddr>, pub Vec<u8>);
+  pub struct TubeSock {
+    pub addr: Option<SocketAddr>,
+    pub rx: Vec<u8>,
+    pub tx: Vec<u8>,
+  }
 
   impl TubeSock {
     pub fn new() -> Self {
-      Self(None, vec![])
+      Self { addr: None,
+             rx: Default::default(),
+             tx: Default::default() }
+    }
+
+    pub fn init(rx: Vec<u8>) -> Self {
+      let mut me = Self::new();
+      me.rx = rx;
+      me
     }
   }
 
@@ -159,18 +171,18 @@ pub(crate) mod test {
     type Error = Option<()>;
 
     fn connect<A: ToSocketAddrs>(&mut self, a: A) -> Result<(), Self::Error> {
-      self.0 = a.to_socket_addrs().unwrap().next();
+      self.addr = a.to_socket_addrs().unwrap().next();
       Ok(())
     }
 
     fn recv(&self, buf: &mut [u8]) -> nb::Result<usize, Self::Error> {
-      if self.1.is_empty() {
-        println!("TubSock recv invoked without sending first");
+      if self.rx.is_empty() {
+        eprintln!("TubeSock recv invoked without any bytes");
         return Err(nb::Error::WouldBlock);
       }
 
-      let n = self.1.len();
-      let vec = &self.1 as *const _ as *mut Vec<u8>;
+      let n = self.rx.len();
+      let vec = &self.rx as *const _ as *mut Vec<u8>;
       unsafe {
         vec.as_mut()
            .unwrap()
@@ -182,7 +194,7 @@ pub(crate) mod test {
     }
 
     fn send(&self, buf: &[u8]) -> nb::Result<(), Self::Error> {
-      let vec = &self.1 as *const _ as *mut Vec<u8>;
+      let vec = &self.tx as *const _ as *mut Vec<u8>;
       unsafe {
         *vec = buf.iter().copied().collect();
       }
