@@ -1,9 +1,12 @@
-pub(crate) trait ResultExt<T, E> {
+pub(crate) trait ResultExt<T, E>: Sized {
   fn bind<R>(self, f: impl FnOnce(T) -> Result<R, E>) -> Result<R, E>;
   fn bind_err<R>(self, f: impl FnOnce(E) -> Result<T, R>) -> Result<T, R>;
   fn try_perform(self, f: impl FnOnce(&T) -> Result<(), E>) -> Result<T, E>;
   fn perform(self, f: impl FnOnce(&T) -> ()) -> Result<T, E>;
   fn filter(self, pred: impl FnOnce(&T) -> bool, on_fail: impl FnOnce(&T) -> E) -> Result<T, E>;
+  fn tupled<R>(self, f: impl FnOnce(&T) -> Result<R, E>) -> Result<(T, R), E> {
+    self.bind(|t| f(&t).map(|r| (t, r)))
+  }
 }
 
 impl<T, E> ResultExt<T, E> for Result<T, E> {
